/**
 * The JavaScript Array global object is a constructor for arrays, which are high-level, list-like objects.
 * @syntax [element0, element1, ..., elementN] new Array(element0, element1, ..., elementN) new Array(arrayLength)
 * @returns {Array} 
 */
function Array(element0,  element1) {
}
/**
 * Changes the content of an array, adding new elements while removing old elements.
 * @syntax array.splice(index , howMany[, element1[, ...[, elementN]]])<br> array.splice(index[, howMany[, element1[, ...[, elementN]]]])
 * @param {Number} index Index at which to start changing the array. If negative, will begin that many elements from the end.
 * @param {Number} howMany An integer indicating the number of old array elements to remove. If howMany is 0, no elements are removed. In this case, you should specify at least one new element. If no howMany parameter is specified (second syntax above, which is a SpiderMonkey extension), all elements after index are removed.
 * @param {Array} element1,...,elementN The elements to add to the array. If you don't specify any elements, splice simply removes elements from the array.
 * @returns {Array} 
 */
Array.prototype.splice = function(index ,  howMany) {};

/**
 * Returns a string representing the source code of the array.
 * @syntax array.toSource()
 * @returns {String} 
 */
Array.prototype.toSource = function() {};

/**
 * Sorts the elements of an array in place and returns the array. Works across all browsers.
 * @syntax array.sort([compareFunction])
 * @param {Array} compareFunction Specifies a function that defines the sort order. If omitted, the array is sorted lexicographically (in dictionary order) according to the string conversion of each element.
 * @returns {Array} 
 */
Array.prototype.sort = function() {};

/**
 * Apply a function simultaneously against two values of the array (from right-to-left) as to reduce it to a single value.
 * @syntax array.reduceRight(callback[, initialValue])
 * @param {Function} callback Function to execute on each value in the array.
 * @param {Object} initialValue Object to use as the first argument to the first call of the callback.
 * @returns {Object} 
 */
Array.prototype.reduceRight = function(callback) {};

/**
 * Removes the last element from an array and returns that element.
 * @syntax array.pop()
 * @returns {Object} 
 */
Array.prototype.pop = function() {};

/**
 * Returns the first index at which a given element can be found in the array, or -1 if it is not present.
 * @syntax array.indexOf(searchElement[, fromIndex])
 * @param {Array} searchElement Element to locate in the array.
 * @param {Number} fromIndex The index at which to begin the search. Defaults to 0, i.e. the whole array will be searched. If the index is greater than or equal to the length of the array, -1 is returned, i.e. the array will not be searched. If negative, it is taken as the offset from the end of the array. Note that even when the index is negative, the array is still searched from front to back. If the calculated index is less than 0, the whole array will be searched.
 * @returns {Number} 
 */
Array.prototype.indexOf = function(searchElement) {};

/**
 * Tests whether all elements in the array pass the test implemented by the provided function.
 * @syntax array.every(callback[, thisObject])
 * @param {Function} callback Function to test for each element.
 * @param {Object} thisObject Object to use as this when executing callback.
 * @returns {Boolean} 
 */
Array.prototype.every = function(callback) {};

/**
 * Mutates an array by appending the given elements and returning the new length of the array.
 * @syntax array.push(element1, ..., elementN)
 * @param {Array} element1,...,elementN The elements to add to the end of the array.
 * @returns {Number} 
 */
Array.prototype.push = function(element1) {};

/**
 * An unsigned, 32-bit integer that specifies the number of elements in an array.
 * @returns {Number} 
 */
Array.prototype.length = new Number();

/**
 * Creates a new array with the results of calling a provided function on every element in this array.
 * @syntax array.map(callback[, thisArg])
 * @param {Function} callback Function that produces an element of the new Array from an element of the current one.
 * @param {Object} thisArg Object to use as this when executing callback.
 * @returns {Array} 
 */
Array.prototype.map = function(callback) {};

/**
 * Adds one or more elements to the beginning of an array and returns the new length of the array.
 * @syntax arrayName.unshift(element1, ..., elementN)
 * @param {Array} element1,...,elementN The elements to add to the front of the array.
 * @returns {Number} 
 */
Array.prototype.unshift = function(element1) {};

/**
 * Returns a reference to the Array function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * @returns {Function} 
 */
Array.prototype.constructor = new Function();

/**
 * Reverses an array in place.  The first array element becomes the last and the last becomes the first.
 * @syntax array.reverse()
 * @returns {Array} 
 */
Array.prototype.reverse = function() {};

/**
 * Executes a provided function once per array element.
 * @syntax array.forEach(callback[, thisArg])
 * @param {Function} callback Function to execute for each element.
 * @param {Object} thisArg Object to use as this when executing callback.
 * @returns {undefined} 
 */
Array.prototype.forEach = function(callback) {};

/**
 * Returns the last index at which a given element can be found in the array, or -1 if it is not present. The array is searched backwards, starting at fromIndex.
 * @syntax array.lastIndexOf(searchElement[, fromIndex])
 * @param {Object} searchElement Element to locate in the array.
 * @param {Number} fromIndex The index at which to start searching backwards. Defaults to the array's length, i.e. the whole array will be searched. If the index is greater than or equal to the length of the array, the whole array will be searched. If negative, it is taken as the offset from the end of the array. Note that even when the index is negative, the array is still searched from back to front. If the calculated index is less than 0, -1 is returned, i.e. the array will not be searched.
 * @returns {Number} 
 */
Array.prototype.lastIndexOf = function(searchElement) {};

/**
 * Joins all elements of an array into a string.
 * @syntax array.join(separator)
 * @param {String} separator Specifies a string to separate each element of the array. The separator is converted to a string if necessary. If omitted, the array elements are separated with a comma.
 * @returns {String} 
 */
Array.prototype.join = function(separator) {};

/**
 * Returns a new array comprised of this array joined with other array(s) and/or value(s).
 * @syntax array.concat(value1, value2, ..., valueN)
 * @param {Array} valueN Arrays and/or values to concatenate to the resulting array.
 * @returns {Array} 
 */
Array.prototype.concat = function(value1,  value2) {};

/**
 * @syntax array.reduce(callback[, initialValue])
 * @param {Function} callback Function to execute on each value in the array, taking four arguments: previousValue The value previously returned in the last invocation of the callback, or initialValue, if supplied. (See below.) currentValue The current element being processed in the array. index The index of the current element being processed in the array. array The array reduce was called upon.
 * @param {Object} initialValue Object to use as the first argument to the first call of the callback.
 * @returns {Object} 
 */
Array.prototype.reduce = function(callback) {};

/**
 * Returns a one-level deep copy of a portion of an array.
 * @syntax array.slice(begin[, end])
 * @param {Number} begin Zero-based index at which to begin extraction.
 * @param {Number} end Zero-based index at which to end extraction. slice extracts up to but not including end.
 * @returns {Array} 
 */
Array.prototype.slice = function(begin) {};

/**
 * Returns a string representing the specified array and its elements.
 * @syntax array.toString()
 * @returns {String} 
 */
Array.prototype.toString = function() {};

/**
 * Returns true if an object is an array, false if it is not.
 * @syntax Array.isArray(obj)
 * @param {Object} obj The object to be checked
 * @returns {Boolean} 
 * @static
 */
Array.isArray = function(obj) {};

/**
 * Tests whether some element in the array passes the test implemented by the provided function.
 * @syntax array.some(callback[, thisObject])
 * @param {Function} callback Function to test for each element.
 * @param {Object} thisObject Object to use as this when executing callback.
 * @returns {Boolean} 
 */
Array.prototype.some = function(callback) {};

/**
 * Removes the first element from an array and returns that element. This method changes the length of the array.
 * @syntax array.shift()
 * @returns {Object} 
 */
Array.prototype.shift = function() {};

/**
 * Creates a new array with all elements that pass the test implemented by the provided function.
 * @syntax array.filter(callback[, thisObject])
 * @param {Function} callback Function to test each element of the array.
 * @param {Object} thisObject Object to use as this when executing callback.
 * @returns {Array} 
 */
Array.prototype.filter = function(callback) {};

/**
 * Represents the prototype for the Array constructor.
 * @returns {Object} 
 * @static
 */
Array.prototype;

