/**
 * Creates JavaScript Date instances which let you work with dates and times.
 * @syntax new Date() new Date(milliseconds) new Date(dateString) new Date(year, month, day [, hour, minute, second, millisecond ])
 * @param {Number} milliseconds Integer value representing the number of milliseconds since 1 January 1970 00:00:00 UTC (Unix Epoch).
 * @param {String} dateString String value representing a date. The string should be in a format recognized by the parse method (IETF-compliant RFC 2822 timestamps).
 * @param {Number} year Integer value representing the year. For compatibility (in order to avoid the Y2K problem), you should always specify the year in full; use 1998, rather than 98.
 * @param {Number} month Integer value representing the month, beginning with 0 for January to 11 for December.
 * @param {Number} day Integer value representing the day of the month (1-31).
 * @param {Number} hour Integer value representing the hour of the day (0-23).
 * @param {Number} minute Integer value representing the minute segment (0-59) of a time reading.
 * @param {Number} second Integer value representing the second segment (0-59) of a time reading.
 * @param {Number} millisecond Integer value representing the millisecond segment (0-999) of a time reading.
 * @returns {Date} 
 */
function Date() {
}
/**
 * Converts a date to a string, returning the "date" portion using the operating system's locale's conventions.
 * @syntax toLocaleDateString()
 * @returns {String} 
 */
Date.prototype.toLocaleDateString = function() {};

/**
 * Returns the seconds in the specified date according to universal time.
 * @syntax getUTCSeconds()
 * @returns {Number} 
 */
Date.prototype.getUTCSeconds = function() {};

/**
 * Sets the year for a specified date according to local time.
 * @syntax setYear(yearValue)
 * @param {Number} yearValue An integer.
 * @returns {Number} 
 */
Date.prototype.setYear = function(yearValue) {};

/**
 * Converts a date to a string, using the universal time convention.
 * @syntax toUTCString()
 * @returns {String} 
 */
Date.prototype.toUTCString = function() {};

/**
 * Sets the full year for a specified date according to universal time.
 * @syntax setUTCFullYear(yearValue[, monthValue[, dayValue]])
 * @param {Number} yearValue An integer specifying the numeric value of the year, for example, 1995.
 * @param {Number} monthValue An integer between 0 and 11 representing the months January through December.
 * @param {Number} dayValue An integer between 1 and 31 representing the day of the month. If you specify the dayValue parameter, you must also specify the monthValue.
 * @returns {Number} 
 */
Date.prototype.setUTCFullYear = function(yearValue) {};

/**
 * Returns the time-zone offset from UTC, in minutes, for the current locale.
 * @syntax getTimezoneOffset()
 * @returns {Number} 
 */
Date.prototype.getTimezoneOffset = function() {};

/**
 * Returns the day of the week for the specified date according to local time.
 * @syntax getDay()
 * @returns {Number} 
 */
Date.prototype.getDay = function() {};

/**
 * Sets the hour for a specified date according to universal time.
 * @syntax setUTCHours(hoursValue[, minutesValue[, secondsValue[, msValue]]])
 * @param {Number} hoursValue An integer between 0 and 23, representing the hour.
 * @param {Number} minutesValue An integer between 0 and 59, representing the minutes.
 * @param {Number} secondsValue An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.
 * @param {Number} msValue A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.
 * @returns {Number} 
 */
Date.prototype.setUTCHours = function(hoursValue) {};

/**
 * Returns the year in the specified date according to local time.
 * @syntax getYear()
 * @returns {Number} 
 */
Date.prototype.getYear = function() {};

/**
 * Sets the minutes for a specified date according to local time.
 * @syntax setMinutes(minutesValue[, secondsValue[, msValue]]) setMinutes(minutesValue)
 * @param {Number} minutesValue An integer between 0 and 59, representing the minutes.
 * @param {Number} secondsValue An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.
 * @param {Number} msValue A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.
 * @returns {Number} 
 */
Date.prototype.setMinutes = function(minutesValue) {};

/**
 * JavaScript provides a direct way to convert a date object into a string in ISO format, the ISO 8601 Extended Format. The Date.prototype.toISOString is an ECMAScript 5 addition. Format is as follows: YYYY-MM-DDTHH:mm:ss.sssZ
 * @syntax myDate.toISOString()
 * @returns {String} 
 */
Date.prototype.toISOString = function() {};

/**
 * Sets the milliseconds for a specified date according to local time.
 * @syntax setMilliseconds(millisecondsValue)
 * @param {Number} millisecondsValue A number between 0 and 999, representing the milliseconds.
 * @returns {Number} 
 */
Date.prototype.setMilliseconds = function(millisecondsValue) {};

/**
 * Accepts the same parameters as the longest form of the constructor, and returns the number of milliseconds in a Date object since January 1, 1970, 00:00:00, universal time.
 * @syntax Date.UTC(year, month[, date[, hrs[, min[, sec[, ms]]]]])
 * @param {Number} year A year after 1900.
 * @param {Number} month An integer between 0 and 11 representing the month.
 * @param {Number} date An integer between 1 and 31 representing the day of the month.
 * @param {Number} hrs An integer between 0 and 23 representing the hours.
 * @param {Number} min An integer between 0 and 59 representing the minutes.
 * @param {Number} sec An integer between 0 and 59 representing the seconds.
 * @param {Number} ms An integer between 0 and 999 representing the milliseconds.
 * @returns {Number} 
 * @static
 */
Date.UTC = function(year,  month) {};

/**
 * Returns the day (date) of the month in the specified date according to universal time.
 * @syntax getUTCDate()
 * @returns {Number} 
 */
Date.prototype.getUTCDate = function() {};

/**
 * @syntax date.toTimeString()
 * @returns {String} 
 */
Date.prototype.toTimeString = function() {};

/**
 * Sets the seconds for a specified date according to local time.
 * @syntax setSeconds(secondsValue[, msValue]) setSeconds(secondsValue)
 * @param {Number} secondsValue An integer between 0 and 59.
 * @param {Number} msValue A number between 0 and 999, representing the milliseconds.
 * @returns {Number} 
 */
Date.prototype.setSeconds = function(secondsValue) {};

/**
 * Sets the seconds for a specified date according to universal time.
 * @syntax setUTCSeconds(secondsValue[, msValue])
 * @param {Number} secondsValue An integer between 0 and 59.
 * @param {Number} msValue A number between 0 and 999, representing the milliseconds.
 * @returns {Number} 
 */
Date.prototype.setUTCSeconds = function(secondsValue) {};

/**
 * Returns the date portion of a Date object in human readable form in American English.
 * @syntax date.toDateString()
 * @returns {String} 
 */
Date.prototype.toDateString = function() {};

/**
 * Returns the day of the month for the specified date according to local time.
 * @syntax getDate()
 * @returns {Number} 
 */
Date.prototype.getDate = function() {};

/**
 * Sets the hours for a specified date according to local time.
 * @syntax setHours(hoursValue[, minutesValue[, secondsValue[, msValue]]]) setHours(hoursValue)
 * @param {Number} hoursValue An integer between 0 and 23, representing the hour.
 * @param {Number} minutesValue An integer between 0 and 59, representing the minutes.
 * @param {Number} secondsValue An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.
 * @param {Number} msValue A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.
 * @returns {Number} 
 */
Date.prototype.setHours = function(hoursValue) {};

/**
 * @syntax var timeInMs = Date.now();
 * @returns {Number} 
 * @static
 */
Date.now = function() {};

/**
 * Returns the year in the specified date according to universal time.
 * @syntax getUTCFullYear()
 * @returns {Number} 
 */
Date.prototype.getUTCFullYear = function() {};

/**
 * Returns the month in the specified date according to local time.
 * @syntax getMonth()
 * @returns {Number} 
 */
Date.prototype.getMonth = function() {};

/**
 * Returns a string representing the specified Date object.
 * @syntax toString()
 * @returns {String} 
 */
Date.prototype.toString = function() {};

/**
 * Sets the day of the month for a specified date according to universal time.
 * @syntax setUTCDate(dayValue)
 * @param {Number} dayValue An integer from 1 to 31, representing the day of the month.
 * @returns {Number} 
 */
Date.prototype.setUTCDate = function(dayValue) {};

/**
 * Sets the month for a specified date according to universal time.
 * @syntax setUTCMonth(monthValue[, dayValue])
 * @param {Number} monthValue An integer between 0 and 11, representing the months January through December.
 * @param {Number} dayValue An integer from 1 to 31, representing the day of the month.
 * @returns {Number} 
 */
Date.prototype.setUTCMonth = function(monthValue) {};

/**
 * Returns the minutes in the specified date according to local time.
 * @syntax getMinutes()
 * @returns {Number} 
 */
Date.prototype.getMinutes = function() {};

/**
 * Converts a date to a string, using the operating system's locale's conventions.
 * @syntax toLocaleString()
 * @returns {String} 
 */
Date.prototype.toLocaleString = function() {};

/**
 * Returns a string representing the source code of the object.
 * @syntax date.toSource()
 * @returns {String} 
 */
Date.prototype.toSource = function() {};

/**
 * Returns the seconds in the specified date according to local time.
 * @syntax getSeconds()
 * @returns {Number} 
 */
Date.prototype.getSeconds = function() {};

/**
 * Returns the month of the specified date according to universal time.
 * @syntax getUTCMonth()
 * @returns {Number} 
 */
Date.prototype.getUTCMonth = function() {};

/**
 * Returns the year of the specified date according to local time.
 * @syntax getFullYear()
 * @returns {Number} 
 */
Date.prototype.getFullYear = function() {};

/**
 * Returns the hour for the specified date according to local time.
 * @syntax getHours()
 * @returns {Number} 
 */
Date.prototype.getHours = function() {};

/**
 * Returns the hours in the specified date according to universal time.
 * @syntax getUTCHours
 * @returns {Number} 
 */
Date.prototype.getUTCHours = function() {};

/**
 * Converts a date to a string using the specified formatting.
 * @syntax dateObj.toLocaleFormat(formatString)
 * @param {String} formatString A format string in the same format expected by the strftime() function in C.
 * @returns {Number} 
 */
Date.prototype.toLocaleFormat = function(formatString) {};

/**
 * Returns the primitive value of a Date object.
 * @syntax valueOf()
 * @returns {Number} 
 */
Date.prototype.valueOf = function() {};

/**
 * Parses a string representation of a date, and returns the number of milliseconds since January 1, 1970, 00:00:00 UTC.
 * @syntax Date.parse(dateString)
 * @param {String} dateString A string representing an RFC2822 or ISO 8601 date.
 * @returns {Number} 
 * @static
 */
Date.parse = function(dateString) {};

/**
 * Returns a reference to the Date function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * @returns {Function} 
 */
Date.prototype.constructor = new Function();

/**
 * Sets the Date object to the time represented by a number of milliseconds since January 1, 1970, 00:00:00 UTC.
 * @syntax setTime(timeValue)
 * @param {Number} timeValue An integer representing the number of milliseconds since 1 January 1970, 00:00:00 UTC.
 * @returns {Number} 
 */
Date.prototype.setTime = function(timeValue) {};

/**
 * Converts a date to a string, returning the "time" portion using the current locale's conventions.
 * @syntax toLocaleTimeString()
 * @returns {String} 
 */
Date.prototype.toLocaleTimeString = function() {};

/**
 * Sets the milliseconds for a specified date according to universal time.
 * @syntax setUTCMilliseconds(millisecondsValue)
 * @param {Number} millisecondsValue A number between 0 and 999, representing the milliseconds.
 * @returns {Number} 
 */
Date.prototype.setUTCMilliseconds = function(millisecondsValue) {};

/**
 * Sets the minutes for a specified date according to universal time.
 * @syntax setUTCMinutes(minutesValue[, secondsValue[, msValue]])
 * @param {Number} minutesValue An integer between 0 and 59, representing the minutes.
 * @param {Number} secondsValue An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.
 * @param {Number} msValue A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.
 * @returns {Number} 
 */
Date.prototype.setUTCMinutes = function(minutesValue) {};

/**
 * Set the month for a specified date according to local time.
 * @syntax setMonth(monthValue[, dayValue]) setMonth(monthValue)
 * @param {Number} monthValue An integer between 0 and 11 (representing the months January through December).
 * @param {Number} dayValue An integer from 1 to 31, representing the day of the month.
 * @returns {Number} 
 */
Date.prototype.setMonth = function(monthValue) {};

/**
 * Sets the day of the month for a specified date according to local time.
 * @syntax setDate(dayValue)
 * @param {Number} dayValue An integer from 1 to 31, representing the day of the month.
 * @returns {Number} 
 */
Date.prototype.setDate = function(dayValue) {};

/**
 * Returns the minutes in the specified date according to universal time.
 * @syntax getUTCMinutes()
 * @returns {Number} 
 */
Date.prototype.getUTCMinutes = function() {};

/**
 * Sets the full year for a specified date according to local time.
 * @syntax setFullYear(yearValue[, monthValue[, dayValue]])
 * @param {Number} yearValue An integer specifying the numeric value of the year, for example, 1995.
 * @param {Number} monthValue An integer between 0 and 11 representing the months January through December.
 * @param {Number} dayValue An integer between 1 and 31 representing the day of the month. If you specify the dayValue parameter, you must also specify the monthValue.
 * @returns {Number} 
 */
Date.prototype.setFullYear = function(yearValue) {};

/**
 * Returns the numeric value corresponding to the time for the specified date according to universal time.
 * @syntax getTime()
 * @returns {Number} 
 */
Date.prototype.getTime = function() {};

/**
 * Returns a JSON representation of the Date object.
 * @syntax date.toJSON()
 * @returns {Number} 
 */
Date.prototype.toJSON = function() {};

/**
 * Returns the day of the week in the specified date according to universal time.
 * @syntax getUTCDay()
 * @returns {Number} 
 */
Date.prototype.getUTCDay = function() {};

/**
 * Converts a date to a string, using Internet GMT conventioins.
 * @syntax toGMTString()
 * @returns {String} 
 */
Date.prototype.toGMTString = function() {};

/**
 * Returns the milliseconds in the specified date according to universal time.
 * @syntax getUTCMilliseconds()
 * @returns {Number} 
 */
Date.prototype.getUTCMilliseconds = function() {};

/**
 * Returns the milliseconds in the specified date according to local time.
 * @syntax getMilliseconds()
 * @returns {Number} 
 */
Date.prototype.getMilliseconds = function() {};

/**
 * Represents the prototype for the Date constructor.
 * @returns {Number} 
 * @static
 */
Date.prototype;

